@@ -49,8 +49,16 @@ meteo_noaa_co2 <- function(){
   temp = tempfile()
   test_url(link = base_url, output = temp)
   
-  co2 = read.table(temp, na.strings = "-99.99")
-  colnames(co2) = c("yy", "mm", "yy_d","co2_avg", "co2_interp", "co2_seas", "ndays")
+  # run only if downloaded file is valid
+  co2 = NULL
+  if(!is.na(file.size(temp)) & (file.size(temp) > 800)) { 
+    
+    co2 = read.table(temp, na.strings = "-99.99")
+    colnames(co2) = c("yy", "mm", "yy_d","co2_avg", "co2_interp", "co2_seas", "ndays")
+    
+  } else {
+    cat(paste0("Service not working or problems with internet connection. Check url:\n", base_url)) 
+  }
     
   unlink(temp)
   return(co2)
